<?php

namespace Litecms\BannedIps\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\BannedIps\Models\BannedIP;

class BannedIPPolicy
{

    /**
     * Determine if the given user can view the banned_i_p.
     *
     * @param UserPolicy $user
     * @param BannedIP $banned_i_p
     *
     * @return bool
     */
    public function view(UserPolicy $user, BannedIP $banned_i_p)
    {
        if ($user->canDo('banned_ips.banned_i_p.view') && $user->isAdmin()) {
            return true;
        }

        return $banned_i_p->user_id == user_id() && $banned_i_p->user_type == user_type();
    }

    /**
     * Determine if the given user can create a banned_i_p.
     *
     * @param UserPolicy $user
     * @param BannedIP $banned_i_p
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('banned_ips.banned_i_p.create');
    }

    /**
     * Determine if the given user can update the given banned_i_p.
     *
     * @param UserPolicy $user
     * @param BannedIP $banned_i_p
     *
     * @return bool
     */
    public function update(UserPolicy $user, BannedIP $banned_i_p)
    {
        if ($user->canDo('banned_ips.banned_i_p.edit') && $user->isAdmin()) {
            return true;
        }

        return $banned_i_p->user_id == user_id() && $banned_i_p->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given banned_i_p.
     *
     * @param UserPolicy $user
     * @param BannedIP $banned_i_p
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BannedIP $banned_i_p)
    {
        return $banned_i_p->user_id == user_id() && $banned_i_p->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given banned_i_p.
     *
     * @param UserPolicy $user
     * @param BannedIP $banned_i_p
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BannedIP $banned_i_p)
    {
        if ($user->canDo('banned_ips.banned_i_p.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given banned_i_p.
     *
     * @param UserPolicy $user
     * @param BannedIP $banned_i_p
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BannedIP $banned_i_p)
    {
        if ($user->canDo('banned_ips.banned_i_p.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
